# Kivy-Widgets

Welcome to the "Kivy Widgets" repository! This repository contains a collection of custom widgets for the Kivy Python library. These widgets are designed to enhance the functionality and user experience of your Kivy applications.

`IconViewer`:
```py
from kivy.app import runTouchApp
from kivy.lang import Builder

from kivy_widgets import color_definitions
from kivy_widgets.icons import IconViewer

runTouchApp(Builder.load_string("""
IconViewer:
"""))
```

https://user-images.githubusercontent.com/23220309/228534067-bab84dda-8910-45f8-be38-1242dada9c17.mp4

## Contributing

We welcome contributions to this repository from the Kivy community. If you have created a custom widget that you think would be a good fit for this repository, please feel free to submit a pull request with your changes.

## License
This repository is licensed under the MIT License, which allows for both personal and commercial use of the code provided. 

## Acknowledgements
We would like to thank the Kivy community for helping to make Kivy a powerful and versatile library for Python developers.
